
# pygmea URL batch downloader

Usage: Creates a list of URLs from the given template. Will replace ```<>``` with numbers and ```<txt>``` with text substitutes. May also load a list of templates from a .txt file.

(c) Carsten Engelke 2023 MIT-License